#
# spec file for package yast2-firstboot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-firstboot
Version:        4.2.15
Release:        lp152.2.3.1
Summary:        YaST2 - Initial System Configuration
License:        GPL-2.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-firstboot

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
BuildRequires:  ruby
BuildRequires:  update-desktop-files
BuildRequires:  yast2-devtools >= 4.2.2

PreReq:         %fillup_prereq
# yast2/NeworkDevices -> yast2/NetworkInterfaces
Requires:       yast2 >= 2.16.23
# Language::SwitchToEnglishIfNeeded
Requires:       yast2-country >= 2.19.5
# Rely on the YaST2-Firstboot.service for halting the system on failure
Requires:       yast2-installation >= 4.1.2
# Use Yast::Lan.write_config to write hostname changes
Requires:       yast2-configuration-management >= 4.1.3
Requires:       yast2-network >= 4.2.74
Requires:       yast2-ruby-bindings >= 1.0.0

# bsc #1165646
Recommends:     (icewm if libyui-qt)

BuildArch:      noarch

%description
The YaST firstboot utility runs after installation is completed.  It
guides the user through a series of steps that allows for easier
configuration of the machine.

YaST firstboot does not run by default and has	to be configured to run
by the user or the system administrator. It is useful for image
deployments where the system in the image is completely configured,
however some last steps like root password and user logins have to be
created to personalize the system.

%prep
%setup -q

%build
%yast_build
# enable registration by default on SLE (bsc#1162846)
%if !0%{?is_opensuse}
# lets explain this sed. At first it is address which match line with name
# registration and +1 for next line and then here change false to true
sed -i '/<name>registration/,+1s/false/true/' control/firstboot.xml
%endif

%install
%yast_install
%yast_metainfo

mkdir -p $RPM_BUILD_ROOT/usr/share/firstboot/scripts

%check
# verify defaults for registration
ruby -r rexml/document -e '
  %if !0%{?is_opensuse}
    expected = "true"
  %else
    expected = "false"
  %endif
  document = REXML::Document.new(File.new("control/firstboot.xml"))
  # get value of enabled element in registration module in control.xml to verify it has expected value
  if document.root.elements["//module[name[text()=\"registration\"]]"].elements["enabled"].get_text != expected
    STDERR.puts "Wrong default for registration module"
    exit 1
  end'

%post
%{fillup_only -n firstboot}

%files
%{yast_ystartupdir}
%{yast_clientdir}
%{yast_libdir}
%{yast_yncludedir}
%{yast_moduledir}
%{yast_scrconfdir}
%{_fillupdir}
%{_datadir}/firstboot
%doc %{yast_docdir}
%license COPYING
%{_sysconfdir}/YaST2
%{_datadir}/autoinstall
%{yast_schemadir}
%{yast_icondir}
%{yast_metainfodir}

%changelog
* Thu Jul 16 2020 Knut Anderssen <kanderssen@suse.com>
- Fix firsboot_hostname client crash (bsc#1173298)
- 4.2.15
* Wed Apr  8 2020 Stefan Hundhammer <shundhammer@suse.com>
- Recommend icewm if graphical installation (bsc#1165646)
- 4.2.14
* Tue Mar 17 2020 Josef Reidinger <jreidinger@suse.com>
- Enable by default registration on SLE (bsc#1162846)
- 4.2.13
* Fri Mar 13 2020 Josef Reidinger <jreidinger@suse.com>
- remember the keyboard selection in the keyboard language dialog
  when the language is selected after the keyboard (bsc#1160164)
- 4.2.12
* Wed Feb 26 2020 Josef Reidinger <jreidinger@suse.com>
- Fix disabled finish button (bsc#1163100)
- 4.2.11
* Tue Jan 21 2020 Ancor Gonzalez Sosa <ancor@suse.com>
- Fix packaging error (bsc#1161224)
- 4.2.10
* Tue Jan 14 2020 Ludwig Nussel <lnussel@suse.de>
- Don't use deprecated Progress.on
- Don't allow to go back in congratulate screen
- Don't try to set keyboard in WSL
- 4.2.9
* Tue Jan 14 2020 Josef Reidinger <jreidinger@suse.com>
- drop starting of hal as it is also obsolete and no longer exist
  (jsc#SLE-10976)
- 4.2.8
* Mon Jan 13 2020 Josef Reidinger <jreidinger@suse.com>
- drop deprecated network technologies (jsc#SLE-7753)
- replace rc* and init.d usage by systemd (jsc#SLE-10976)
- 4.2.7
* Wed Dec 18 2019 Ancor Gonzalez Sosa <ancor@suse.com>
- Replace outdated "SuSE" spelling (bsc#970809).
- 4.2.6
* Fri Dec 13 2019 David Diaz <dgonzalez@suse.com>
- Improve the "firstboot_licenses" client to give precedence to
  the directory argument, allowing to use it multiple times to show
  different licenses (bsc#1154708).
- Remove the references to the already dropped automatic
  configuration feature (FATE#314695).
- 4.2.5
* Fri Oct 11 2019 schubi@suse.de
- Adapted to refactored Keyboard module (part of bsc#1142957).
- 4.2.4
* Tue Oct  1 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Removed call to the already dropped DNS.write_hostname= method
  (related to boo#1152627).
- 4.2.3
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.2
* Mon Jul 15 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Do not rely on the already dropped DNS.proposal_valid method
  (related to bsc#1140199).
- 4.2.1
* Sat Jun  8 2019 Stasiek Michalski <hellcp@mailbox.org>
- Use new schema of desktop files (boo#1084864)
- Clean up spec
- Rename desktop files
- 4.2.0
* Mon May 13 2019 David Diaz <dgonzalez@suse.com>
- Update the firstboot.xml template to use the "firstboot_licenses"
  client for the license agreement.
- Adapt the "firstboot_licenses" client to cover all possible
  scenarios: to display the Novell license agreement, the vendor
  license agreement, both or simply the default one (bsc#1131327).
- 4.1.7
* Thu Apr 11 2019 lnussel@suse.de
- Disable duplicate license dialogs (boo#131301)
- Initialize product in firstboot (boo#1132189)
- 4.1.6
* Fri Feb  8 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Support going back when using the yast2-configuration-management
  module integration (fate#322722).
- 4.1.5
* Fri Jan 25 2019 igonzalezsosa@suse.com
- Add integration with the yast2-configuration-management module
  (fate#322722).
- 4.1.4
* Fri Jan 11 2019 lslezak@suse.cz
- Fixed textdomain name (bsc#1121643)
- 4.1.3
* Thu Dec  6 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.2
* Thu Nov 29 2018 schubi@suse.de
- Added firstboot.rnc file to desktop file. This is needed for
  building yast2-schema (bnc#1117068).
- 4.1.1
* Sun Nov 25 2018 Stasiek Michalski <hellcp@mailbox.org>
- Provide icon with module (boo#1109310)
- 4.1.0
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Wed Aug  8 2018 knut.anderssen@suse.com
- Import missing GetInstArgs module in firstboot_write client
  (bsc#1104158)
- 4.0.6
* Mon Jun 11 2018 knut.anderssen@suse.com
- Allow going back from finish step and unified halt (bsc#1095253)
- 4.0.5
* Tue Mar 20 2018 lslezak@suse.cz
- Added firstboot.glade symlink to include also the firstboot.xml
  texts in the generated POT file, removed the old Makefile hack
  (bsc#1085888)
- 4.0.4
* Thu Feb  8 2018 jsrain@suse.cz
- adapted to changes in the Language module (bsc#1079852)
- 4.0.3
* Tue Jan 16 2018 schubi@suse.de
- Do not initialize firstboot in AutoYaST upgrade mode.
  (Additial fix for bnc#1075744)
- 4.0.2
* Thu Nov 30 2017 knut.anderssen@suse.com
- Bring back HostnameDialog adding it into firstboot_hostname once
  it was removed from yast2-network (bsc#1028371, bsc#1070388).
- 4.0.1
* Thu Nov 30 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468).
- 4.0.0
* Wed Aug 24 2016 jreidinger@suse.com
- fix not showing errors as popup in firstboot (bnc#994892)
- 3.1.17
* Fri Aug 12 2016 ancor@suse.com
- Faster response when the user skips the creation of a new user
  (bsc#992245).
- 3.1.16
* Thu Aug 11 2016 ancor@suse.com
- Reimplemented "create user" and "root password" steps to reuse
  the new installation dialogs instead of the obsolete ones.
- More sensible order for the mentioned steps in the default
  configuration file.
- Removed from the default configuration file the obsolete step
  for configuring authentication.
- bsc#992245, bsc#991863
- 3.1.15
* Tue Jun  7 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- 3.1.14
* Thu May 12 2016 igonzalezsosa@suse.com
- Remove kbd service restart because it does not exist anymore
  (bsc#974489)
- Fixed firstboot.xml to call the correct client for registration
  (bsc#970572) (lslezak@suse.cz)
- 3.1.13
* Wed Apr 13 2016 jreidinger@suse.com
- Do not overwrite bootloader configuration in first boot
  (related to FATE#317701)
- 3.1.12
* Mon Jan  4 2016 ancor@suse.com
- Fixed firstboot.xml to call the correct client for LAN
  configuration (bsc#960081)
- 3.1.11
* Fri Oct 16 2015 ancor@suse.com
- Fixed to always use the configured keyboard layout (bsc#950335)
- 3.1.10
* Thu Apr 16 2015 locilka@suse.com
- Forcing mode "installation" for firstboot to always use the
  correct workflow (bsc#924278)
- 3.1.9
* Thu Feb  5 2015 ancor@suse.com
- Fixed the step for host name configuration
  (bnc#911952, bnc#802822)
- 3.1.8
* Thu Dec 18 2014 lslezak@suse.cz
- fixed bashisms in "S09-cleanup" script (authored by "Ledest")
- 3.1.7
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Tue Nov 18 2014 ancor@suse.com
- Added missing module for DHCP (bnc#895359, bnc#904527).
- Fixed errors in keyboard and language configuration (bnc#904527).
- 3.1.5
* Wed Sep 17 2014 mfilka@suse.com
- bnc#895359
  - added client for nic cards autoconfiguration
- 3.1.4
* Wed Jul  9 2014 schubi@suse.de
- Added gnome-classic to gnome WM. (part of bnc#886367)
- 3.1.3
* Wed Jul  9 2014 schubi@suse.de
- Setting gdm if windowmanger is sle-classic (bnc#886367)
- 3.1.2
* Tue May  6 2014 mfilka@suse.com
- bnc#858978
  - updated control file (workflow) to enable NIC autoconfiguration
- 3.1.1
* Wed Sep 18 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Fri Sep 13 2013 lslezak@suse.cz
- properly symlink firstboot.xml file (for collecting translatable
  strings by "make pot")
- removed obsolete BuildRequires (perl-XML-Writer, sgml-skel,
  yast2, yast2-installation, yast2-testsuite, yast2-xml)
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Thu Jul  4 2013 jreidinger@suse.com
- remove obsolete client product_start
- 2.24.0
* Thu Feb 21 2013 jsuchome@suse.cz
- remove references to SuSEconfig (bnc#804936)
- 2.23.1
* Wed Nov  7 2012 jsuchome@suse.cz
- save Product Features at the end (bnc#784588)
- 2.23.0
* Tue Apr 24 2012 ug@suse.de
- added schema check file for autoyast
* Thu Mar 29 2012 jsuchome@suse.cz
- merged proofed texts
- 2.22.1
* Fri Jan 13 2012 jsuchome@suse.cz
- confirmed license
- 2.22.0
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Sep 23 2011 lslezak@suse.cz
- removed obsoleted Pkg::*Selection*() calls
- 2.21.2
* Thu Sep 22 2011 jsuchome@suse.cz
- 2.21.1
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Fri Jul 22 2011 locilka@suse.cz
- Removed obsoleted X-KDE-SubstituteUID from desktop file
  (bnc#540627)
- 2.21.0
* Fri Feb 18 2011 jsuchome@suse.cz
- call stop_unicode before kbd restart (bnc#665504)
- docu update
- 2.20.2
* Wed Nov  3 2010 jsuchome@suse.cz
- translate bootloader items after setting the language (bnc#644062)
- 2.20.1
* Wed Nov  3 2010 jsuchome@suse.cz
- fix FIRSTBOOT_FINISH_FILE behavior and documentation (bnc#615146)
- 2.20.0
* Fri Apr 23 2010 ug@suse.de
- desktop file fixed
- 2.19.5
* Fri Apr  9 2010 jsuchome@suse.cz
- added some default values and comments to firstboot.xml
  (bnc#594751,#594776)
- 2.19.4
* Thu Mar 18 2010 jsuchome@suse.cz
- retranslate wizard steps after language change (bnc#588569)
- 2.19.3
* Tue Feb  2 2010 jsuchome@suse.cz
- fixed string in default firstboot.xml (bnc#576020)
* Mon Jan 11 2010 jsuchome@suse.cz
- set the displaymanager only when respective package is installed
  (bnc#538998)
- 2.19.2
* Thu Jan  7 2010 jsuchome@suse.cz
- added firstboot_licenses step able to show 2 license texts
  (fate#306295)
- adapt to Language::SwitchToEnglishIfNeeded (bnc#479529)
- 2.19.1
* Tue Dec 22 2009 jsuchome@suse.cz
- handle arguments from control file (bnc#566669)
- 2.19.0
* Tue Oct 27 2009 jsuchome@suse.cz
- package firstboot_language_keyboard.ycp file (fate#306296)
- 2.18.10
* Tue Oct 27 2009 jsuchome@suse.cz
- fixed example firstboot.xml: correct client name
- 2.18.9
* Thu Aug 20 2009 jsuchome@suse.cz
- adapted help text (keyboard configuration is gone)
- 2.18.8
* Thu Jul 30 2009 jsuchome@suse.cz
- adapted to changes in yast2-country: no saving of xorg.conf
  (bnc#441404)
- 2.18.7
* Thu Jul 16 2009 jsuchome@suse.cz
- added example for root_password_as_first_user (fate#306297) into
  default firstboot.xml
- 2.18.6
* Thu Jul 16 2009 jsuchome@suse.cz
- added step for both language and keyboard layout (fate#306296)
- 2.18.5
* Tue Jul  7 2009 jsuchome@suse.cz
- added option to do reboot at the end of firstboot (bnc#514745)
- 2.18.4
* Thu Jun 18 2009 jsuchome@suse.cz
- 2.18.3
* Tue Jun 16 2009 mvidner@suse.cz
- Using autodocs-ycp.ami, which contains a fix for automake 1.11.
* Mon Jun  1 2009 jsuchome@suse.cz
- call the X11 config to save kbd layout (bnc#497819)
- 2.18.2
* Tue Apr 14 2009 jsuchome@suse.cz
- grab texts from firstboot.xml when creating pot file (bnc#479571)
- added more generic steps
- 2.18.1
* Wed Feb 25 2009 jsuchome@suse.cz
- start the services before YaST (bnc#475169)
- set the reasonable value for LC_ALL (bnc#478812)
- retranslate wizard steps after language change (bnc#479571)
- 2.18.0
* Fri Jan  9 2009 ug@suse.de
- firstboot.desktop file moved from autoyast2 package to this
  package
* Wed Dec 10 2008 jsuchome@suse.cz
- removed reference to obsolete control.dtd (bnc#455994)
- 2.17.5
* Wed Sep 17 2008 jsuchome@suse.cz
- added client for NTP configuration
- 2.17.4
* Fri Aug 22 2008 jsrain@suse.cz
- added missing firstboot_finish.ycp to package, fixed typo,
  adapted documentation (bnc #407075)
- 2.17.3
* Thu Jul 24 2008 jsuchome@suse.cz
- document the usage of Automatic Configuration (fate#303939)
- 2.17.2
* Tue Jul 22 2008 jsuchome@suse.cz
- addedd support fot autoyast (fate#301946):
    client for firstboot enablement
    configurable path to firstboot.xml
    adapted documentation
- 2.17.1
* Tue Jul 15 2008 jsuchome@suse.cz
- added default location of Novell license texts (fate#304865)
- enabled license clients by default
- adapted documentation
- 2.17.0
* Mon Mar 17 2008 jsrain@suse.cz
- adapted documentation regarding enabling firstboot service,
  removed /etc/init.d/firstboot (bnc#354738)
- 2.16.4
* Thu Jan 24 2008 mzugec@suse.cz
- replace deprecated NetworkDevices by NetworkInterfaces (from yast2)
- 2.16.3
* Fri Nov  2 2007 locilka@suse.cz
- Adjusted RPM dependencies (added modules in use: yast2-bootloader
  yast2-country, removed yast2-network).
- Removed unneeded SourceManager import.
- Fixed deprecated 'lookup' call.
- 2.16.2
* Wed Oct 24 2007 jsrain@suse.cz
- added firstboot_bootloader to recreate bootloader configuration
* Tue Oct 23 2007 jsrain@suse.cz
- initialize package callbacks, since some of the modules run
  in the firstboot workflow expect them being initialized (#335979)
- 2.16.1
* Fri Oct 19 2007 jsuchome@suse.cz
- added support for keyboard and restaring network (#F302520)
- added one more client for showing the license + new value
  FIRSTBOOT_NOVELL_LICENSE_DIR to /etc/sysconfig/firstboot (F302865)
- restart kbd after yast is finished (#303808)
- unset LC_ALL before starting firstboot stage (#252780)
- retranslate buttons after language module (#252780)
- 2.16.0
* Wed Feb 28 2007 lslezak@suse.cz
- Halt the system (configurable in LICENSE_REFUSAL_ACTION) if the
  firstboot workflow is aborted (prevent from skipping the
  license agreement) (#247552)
- 2.15.1
* Fri Jan  5 2007 jsrain@suse.cz
- add (by-default disabled) re-creation of SSH keys and setting
  host name to the firstboot workflow (fate 301246)
- 2.15.0
* Mon Nov 13 2006 lslezak@suse.cz
- 2.14.0
* Wed Nov  1 2006 lslezak@suse.cz
- removed SLES9 license (#207283, #206540), removed other
  useless message files
- added firstboot_license client to display he license,
  updated documentation (#206549)
- halt the system if the license is not accepted and the action
  is set to "halt" (#211118)
- added firstboot_welcome client to display a welcome message
- 2.13.4
* Mon Sep 25 2006 jsrain@suse.cz
- don't redirect stdout of YaST firstboot to /dev/null (#190287)
* Thu Aug 31 2006 lslezak@suse.cz
- the control file has been updated to the default
  workflow (#200718)
- added missing documentation files (#189358)
- 2.13.3
* Tue Aug  1 2006 jsrain@suse.cz
- updated the documentation (#189358)
* Fri Jun  2 2006 jsrain@suse.cz
- log Report messages by default (#180862)
- 2.13.2
* Mon Mar 27 2006 jsrain@suse.de
- updated BuildRequires
- 2.13.1
* Mon Oct 31 2005 jsrain@suse.cz
- fixed XML syntax in firstboot.xml (#130175)
- 2.13.0
* Tue Aug 16 2005 jsrain@suse.cz
- fixed location of the firstboot control file (#104864)
- 2.12.1
* Fri Aug 12 2005 jsrain@suse.cz
- fixed check_ycp errors
- 2.12.0
* Wed Mar  2 2005 nashif@suse.de
- Fixed control file
- import Firstboot module
* Fri Feb 11 2005 nashif@suse.de
- Use general dialogs (welcome, license, finish) from installation
* Thu Feb 10 2005 visnov@suse.cz
- Merged messages from proofreading
* Mon Jan 24 2005 nashif@suse.de
- Use new workflow arguments and new startup scripts
* Tue Nov 30 2004 nashif@suse.de
- Adapted startup scripts to new scheme
* Tue Aug 31 2004 sh@suse.de
- Merged messages from proofreading
- 2.10.3
* Tue Aug 24 2004 nashif@suse.de
- Added desktop selection
- Fixed init script
* Fri Aug 13 2004 nashif@suse.de
- Adde control file specific for firstboot
- Support more clients
- 2.10.1
* Tue Jul 27 2004 nashif@suse.de
- Added missing help texts
- adapted neededforbuild
* Mon Jul 12 2004 nashif@suse.de
- initial version. (#43318)
